@@ -70,6 +70,3 @@ def loop_fn(model, optimizer, loss_fn, trainset, valset, batch_size, max_patienc
             patience -= 1
             if patience == 0:
                 break
-
-    del model
-    del optimizer
